Stan Math Library: stan/math/prim/scal/fun/logit.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

logit.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_FUN_LOGIT_HPP
2 #define STAN_MATH_PRIM_SCAL_FUN_LOGIT_HPP
3
4 #include <boost/math/tools/promotion.hpp>
5
6 namespace stan {
7 namespace math {
8
42 template <typename T>
43 inline typename boost::math::tools::promote_args<T>::type
44 logit(const T a) {
45 using std::log;
46 return log(a / (1.0 - a));
47 }
48
49 }
50 }
51
52 #endif
stan
Definition: log_sum_exp.hpp:8
stan::math::log
fvar< T > log(const fvar< T > &x)
Definition: log.hpp:15
stan::math::logit
fvar< T > logit(const fvar< T > &x)
Definition: logit.hpp:17

[ Stan Home Page ] © 2011–2016, Stan Development Team.